@@ -1,7 +1,8 @@
 from pkg_resources import get_distribution
-from PyQt6.QtWidgets import QMainWindow, QStackedWidget, QWidget
+from PyQt5.QtWidgets import QMainWindow, QStackedWidget, QDesktopWidget
 from ..pages.home_page import BadgerHomePage
 from ..pages.routine_page import BadgerRoutinePage
+from ..pages.run_page import BadgerRunPage
 
 
 class BadgerMainWindow(QMainWindow):
@@ -15,16 +16,18 @@ class BadgerMainWindow(QMainWindow):
         version = get_distribution('badger-opt').version
         self.setWindowTitle(f'Badger v{version}')
         # self.setWindowIcon(QIcon('badger.png'))
-        self.resize(864, 648)
+        self.resize(960, 720)
         self.center()
 
         # Add pages
-        self.home_page = BadgerHomePage(self.show_routine_page)
+        self.home_page = BadgerHomePage(self.show_routine_page, self.show_run_page)
         self.routine_page = BadgerRoutinePage(self.show_home_page)
+        self.run_page = BadgerRunPage(self.show_routine_page, self.show_home_page)
 
         self.stacks = stacks = QStackedWidget()
         stacks.addWidget(self.home_page)
         stacks.addWidget(self.routine_page)
+        stacks.addWidget(self.run_page)
 
         stacks.setCurrentIndex(0)
 
@@ -32,7 +35,7 @@ class BadgerMainWindow(QMainWindow):
 
     def center(self):
         qr = self.frameGeometry()
-        cp = self.screen().availableGeometry().center()
+        cp = QDesktopWidget().availableGeometry().center()
 
         qr.moveCenter(cp)
         self.move(qr.topLeft())
@@ -48,3 +51,8 @@ class BadgerMainWindow(QMainWindow):
         self.home_page.refresh_ui()
         self.home_page.reconfig_logic()
         self.stacks.setCurrentIndex(0)
+
+    def show_run_page(self):
+        self.run_page.refresh_ui()
+        self.run_page.reconfig_logic()
+        self.stacks.setCurrentIndex(2)
